Struct sc_consensus::block_import::BlockImportParams [−][src]
#[non_exhaustive]pub struct BlockImportParams<Block: BlockT, Transaction> {Show 13 fields
pub origin: BlockOrigin,
pub header: Block::Header,
pub justifications: Option<Justifications>,
pub post_digests: Vec<DigestItem>,
pub body: Option<Vec<Block::Extrinsic>>,
pub indexed_body: Option<Vec<Vec<u8>>>,
pub state_action: StateAction<Block, Transaction>,
pub finalized: bool,
pub intermediates: HashMap<Cow<'static, [u8]>, Box<dyn Any + Send>>,
pub auxiliary: Vec<(Vec<u8>, Option<Vec<u8>>)>,
pub fork_choice: Option<ForkChoiceStrategy>,
pub import_existing: bool,
pub post_hash: Option<Block::Hash>,
}Expand description
Data required to import a Block.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.origin: BlockOriginOrigin of the Block
header: Block::HeaderThe header, without consensus post-digests applied. This should be in the same state as it comes out of the runtime.
Consensus engines which alter the header (by adding post-runtime digests)
should strip those off in the initial verification process and pass them
via the post_digests field. During block authorship, they should
not be pushed to the header directly.
The reason for this distinction is so the header can be directly re-executed in a runtime that checks digest equivalence – the post-runtime digests are pushed back on after.
justifications: Option<Justifications>Justification(s) provided for this block from the outside.
post_digests: Vec<DigestItem>Digest items that have been added after the runtime for external work, like a consensus signature.
body: Option<Vec<Block::Extrinsic>>The body of the block.
indexed_body: Option<Vec<Vec<u8>>>Indexed transaction body of the block.
state_action: StateAction<Block, Transaction>Specify how the new state is computed.
finalized: boolIs this block finalized already?
true implies instant finality.
intermediates: HashMap<Cow<'static, [u8]>, Box<dyn Any + Send>>Intermediate values that are interpreted by block importers. Each block importer, upon handling a value, removes it from the intermediate list. The final block importer rejects block import if there are still intermediate values that remain unhandled.
auxiliary: Vec<(Vec<u8>, Option<Vec<u8>>)>Auxiliary consensus data produced by the block.
Contains a list of key-value pairs. If values are None, the keys
will be deleted.
fork_choice: Option<ForkChoiceStrategy>Fork choice strategy of this import. This should only be set by a
synchronous import, otherwise it may race against other imports.
None indicates that the current verifier or importer cannot yet
determine the fork choice value, and it expects subsequent importer
to modify it. If None is passed all the way down to bottom block
importer, the import fails with an IncompletePipeline error.
import_existing: boolRe-validate existing block.
post_hash: Option<Block::Hash>Cached full header hash (with post-digests applied).
Implementations
Create a new block import params.
Get the post header.
pub fn clear_storage_changes_and_mutate<Transaction2>(
self
) -> BlockImportParams<Block, Transaction2>
pub fn clear_storage_changes_and_mutate<Transaction2>(
self
) -> BlockImportParams<Block, Transaction2>
Auxiliary function for “converting” the transaction type.
Actually this just sets StorageChanges::Changes to None and makes rustc think that
Self now uses a different transaction type.
Take intermediate by given key, and remove it from the processing list.
Get a reference to a given intermediate.
Get a mutable reference to a given intermediate.
Check if this block contains state import action